@@ -1,8 +1,7 @@
 import os
 from pprint import pprint
 from pygqlc import GraphQLClient
-from .worker import ValiotWorker
-from .worker import QueueType
+from .worker import ValiotWorker, QueueType, PollingMode, JobConfigMode
 # ! Create main helpers:
 gql = GraphQLClient()
 vw = ValiotWorker()
@@ -15,6 +14,8 @@ gql.addEnvironment(
     default=True)
 vw.setClient(gql)
 vw.setWorker(os.environ.get('WORKER'))
+vw.setPollingMode(PollingMode.SUBSCRIPTION)
+vw.setJobConfigMode(JobConfigMode.SYNC)
 
 
 @vw.job(
@@ -25,7 +26,7 @@ vw.setWorker(os.environ.get('WORKER'))
     enabled=True,
     queueType=QueueType.FREQUENCY,
 )
-def test_job(job_id, update_job, kwargs):
+def test_job(job_id, update_job, **_):
     print("Hi, I'm test job #1")
     update_job({
         'id': job_id,
@@ -43,7 +44,7 @@ def test_job(job_id, update_job, kwargs):
     enabled=True,
     queueType=QueueType.FREQUENCY,
 )
-def test_job_2(job_id, update_job, kwargs):
+def test_job_2(job_id, update_job, **_):
     print("Hi, I'm test job #2")
     update_job({
         'id': job_id,
@@ -55,7 +56,7 @@ def test_job_2(job_id, update_job, kwargs):
 
 def main():
     print('main for valiot worker')
-    vw.run()
+    vw.run(interval=5.0)
 
 
 if __name__ == "__main__":
