@@ -27,6 +27,8 @@ import traceback
 import functools
 
 # helps to know if a function has been called at least once
+
+
 def trackcalls(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
@@ -327,7 +329,7 @@ class ValiotWorker():
         self.log(LogLevel.ERROR, 'Function not found :(')
         message = 'Funcion no habilitada, favor de contactar a administrador'
         notificationData = {}
-        if(nextNotifOld(kwargs['job'])):
+        if (nextNotifOld(kwargs['job'])):
             data, errors = self.gql.mutate(mutations.create_notification, {
                 'context': 'DANGER',
                 'title': f'Error en {kwargs["job"]["queue"]["alias"]}',
@@ -603,8 +605,9 @@ class ValiotWorker():
                 'queue': __.get(job, 'queue.name'),
                 'context': json.dumps(context)
             })
-        
-        log_from_job = self.getProcessLoggerFunction(queue=job['queue'], job=job)
+
+        log_from_job = self.getProcessLoggerFunction(
+            queue=job['queue'], job=job)
         src_status_conn, dst_status_conn = Pipe()
 
         def get_job_status():
@@ -877,20 +880,22 @@ class ValiotWorker():
                 finished.append(job_id)
         for f in finished:
             self.runningJobs.pop(f, None)  # remove any finished jobs
-    
-    def finish_job_gracefully(self, job, job_kwargs, output, errors = []):
+
+    def finish_job_gracefully(self, job, job_kwargs, output, errors=[]):
         if len(errors) > 0:
             self.log(LogLevel.ERROR,
-                f"terminating job with ID {job['id']} with errors...")
+                     f"terminating job with ID {job['id']} with errors...")
             return uploaders.update_job({
                 'id': job['id'],
                 'status': JobStatus.ERROR.value,
                 'output': json.dumps({'data': output, 'errors': errors})
             })
         elif output is None:
-            self.log(LogLevel.INFO, f"finished job with ID {job['id']} with implicit exit")
+            self.log(LogLevel.INFO,
+                     f"finished job with ID {job['id']} with implicit exit")
         elif type(output) == str:
-            self.log(LogLevel.INFO, f"finished job with ID {job['id']} with message: \n{output}")
+            self.log(
+                LogLevel.INFO, f"finished job with ID {job['id']} with message: \n{output}")
         elif type(output) == dict:
             self.log(
                 LogLevel.INFO, f"finished job with ID {job['id']} with data: \n{output}")
@@ -898,20 +903,21 @@ class ValiotWorker():
         # if the job did call "update_job", we gotta make sure we don't override the last info sent explicitly:
         update_job_fn = job_kwargs["update_job"]
         if update_job_fn.has_been_called:
-            maybe_status = update_job_fn.call_args[0].get("status") if len(update_job_fn.call_args) > 0 else None
+            maybe_status = update_job_fn.call_args[0].get(
+                "status") if len(update_job_fn.call_args) > 0 else None
             if maybe_status is not None:
                 last_status = JobStatus(maybe_status)
                 if (last_status in [JobStatus.FINISHED, JobStatus.ERROR, JobStatus.ABORTED, JobStatus.PAUSED]):
                     # job had already been finished explicitly
-                    self.log(LogLevel.INFO, f"job {job['id']} terminated itself correctly")
+                    self.log(LogLevel.INFO,
+                             f"job {job['id']} terminated itself correctly")
                     return
                 # if it was been called, but had a status of "RUNNING", it still requires an implicit termination:
         return uploaders.update_job({
-            'id': job['id'], 
+            'id': job['id'],
             'status': JobStatus.FINISHED.value,
             'output': json.dumps({'data': output, 'errors': []})
-            })
-        
+        })
 
     def unlockFinishedJobs(self, force=False):
         """This function updates all finished jobs to unlock them..
@@ -1134,7 +1140,8 @@ class ValiotWorker():
                     "error": error
                 })
             finally:
-                self.finish_job_gracefully(job=job, job_kwargs=kwargs, output=output, errors=errors)
+                self.finish_job_gracefully(
+                    job=job, job_kwargs=kwargs, output=output, errors=errors)
         p = self.context.Process(target=safe_fn, kwargs=(kwargs))
         p.start()
         self.runningJobs[job['id']] = {
@@ -1283,7 +1290,7 @@ class ValiotWorker():
         job : int, optional
           ID for the job sending this message, by default 0
         """
-        job_zero_padding = len(str(__.get(self.worker, 'jobs.0.id')))        
+        job_zero_padding = len(str(__.get(self.worker, 'jobs.0.id')))
         log_queue_key = __.get(queue, 'name', 'main')
         log_queue = self.logQueues[log_queue_key]
         # to log this in a single line, we prefer to keep it small
@@ -1295,7 +1302,8 @@ class ValiotWorker():
             W = self.worker["code"]
             Q = __.get(queue, 'code', "WORKER_PROCESS")
             J = __.get(job, 'id', 0)
-            def sendLogToQueue(level, message, extra = {}):
+
+            def sendLogToQueue(level, message, extra={}):
                 D = getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
                 log_queue.put({
                     'level': level,
@@ -1307,7 +1315,7 @@ class ValiotWorker():
                     'extra': extra
                 })
         elif self.loggingStyle == LogStyle.PREFIX_ALL_LINES:
-            def sendLogToQueue(level, message, extra = {}):
+            def sendLogToQueue(level, message, extra={}):
                 D = getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
                 msgs = message.split('\n')
                 for msg in msgs:
@@ -1316,7 +1324,7 @@ class ValiotWorker():
                         'content': f'[D={D}/W={W}/Q={Q}/J={J}] - {msg}'
                     })
         else:
-            def sendLogToQueue(level, message, extra = {}):
+            def sendLogToQueue(level, message, extra={}):
                 D = getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
                 log_queue.put({
                     'level': level,
